[Blends-commit] r2475 - /blends/trunk/webtools/blendstasktools.py

tille at users.alioth.debian.org tille at users.alioth.debian.org
Mon Nov 22 21:20:19 UTC 2010


Author: tille
Date: Mon Nov 22 21:20:18 2010
New Revision: 2475

URL: http://svn.debian.org/wsvn/blends/?sc=1&rev=2475
Log:
Do not raise awareness if latest upstream is in experimental

Modified:
    blends/trunk/webtools/blendstasktools.py

Modified: blends/trunk/webtools/blendstasktools.py
URL: http://svn.debian.org/wsvn/blends/blends/trunk/webtools/blendstasktools.py?rev=2475&op=diff
==============================================================================
--- blends/trunk/webtools/blendstasktools.py (original)
+++ blends/trunk/webtools/blendstasktools.py Mon Nov 22 21:20:18 2010
@@ -304,7 +304,7 @@
 
 # Obtain upstream version in case it is newer than Debian version
 query = """PREPARE pkg_dehs (text) AS
    SELECT DISTINCT d.source, unstable_upstream, unstable_parsed_version, unstable_status FROM dehs d
       JOIN  packages p ON p.source = d.source
       WHERE p.package = $1 AND unstable_status = 'outdated' ;"""
 curs.execute(query)
@@ -647,9 +647,11 @@
         curs.execute(query)
         if curs.rowcount > 0:
             row = RowDictionaries(curs)[0]
-            self.outdated['release']       = 'upstream'
-            self.outdated['version']       = row['unstable_upstream']
-            self.outdated['architectures'] = ''
+            # it might be that the new upstream goes to experimental - this should be ignored here
+            if row['experimental_status'] != 'uptodate':
+                self.outdated['release']       = 'upstream'
+                self.outdated['version']       = row['unstable_upstream']
+                self.outdated['architectures'] = ''
 
         query = "EXECUTE popcon ('%s')" % (self.pkg)
         curs.execute(query)
@@ -304,7 +304,7 @@
 # Obtain upstream version in case it is newer than Debian version
 query = """PREPARE pkg_dehs (text) AS
-   SELECT DISTINCT d.source, unstable_upstream, unstable_parsed_version, unstable_status FROM dehs d
+   SELECT DISTINCT d.source, unstable_upstream, unstable_parsed_version, unstable_status, experimental_parsed_version, experimental_status FROM dehs d
       JOIN  packages p ON p.source = d.source
       WHERE p.package = $1 AND unstable_status = 'outdated' ;"""




More information about the Blends-commit mailing list